@@ -1,9 +1,24 @@
 import logging
+import sys
+import typing
+
+if sys.version_info >= (3, 8):
+    from functools import cached_property as threaded_cached_property
+else:
+    from cached_property import threaded_cached_property
+
+from lxml import etree
 
 from zeep.utils import qname_attr
 from zeep.xsd.const import xsd_ns, xsi_ns
+from zeep.xsd.context import XmlParserContext
+from zeep.xsd.elements.base import Base
 from zeep.xsd.types.base import Type
-from zeep.xsd.valueobjects import AnyObject
+from zeep.xsd.valueobjects import AnyObject, CompoundValue
+
+if typing.TYPE_CHECKING:
+    from zeep.xsd.schema import Schema
+    from zeep.xsd.types.complex import ComplexType
 
 logger = logging.getLogger(__name__)
 
@@ -12,41 +27,50 @@ __all__ = ["AnyType"]
 
 class AnyType(Type):
     _default_qname = xsd_ns("anyType")
-    _attributes_unwrapped = []
-    _element = None
+    _element: typing.Optional[Base] = None
 
     def __call__(self, value=None):
         return value or ""
 
-    def render(self, parent, value, xsd_type=None, render_path=None):
+    def render(
+        self,
+        node: etree._Element,
+        value: typing.Union[list, dict, CompoundValue],
+        xsd_type: "ComplexType" = None,
+        render_path=None,
+    ) -> None:
+        assert xsd_type is None
+
         if isinstance(value, AnyObject):
             if value.xsd_type is None:
-                parent.set(xsi_ns("nil"), "true")
+                node.set(xsi_ns("nil"), "true")
             else:
-                value.xsd_type.render(parent, value.value, None, render_path)
-                parent.set(xsi_ns("type"), value.xsd_type.qname)
-        elif hasattr(value, "_xsd_elm"):
-            value._xsd_elm.render(parent, value, render_path)
-            parent.set(xsi_ns("type"), value._xsd_elm.qname)
+                value.xsd_type.render(node, value.value, None, render_path)
+                node.set(xsi_ns("type"), value.xsd_type.qname)
+        elif isinstance(value, CompoundValue):
+            value._xsd_elm.render(node, value, render_path)
+            node.set(xsi_ns("type"), value._xsd_elm.qname)
         else:
-            parent.text = self.xmlvalue(value)
+            node.text = self.xmlvalue(value)
 
     def parse_xmlelement(
-        self, xmlelement, schema=None, allow_none=True, context=None, schema_type=None
-    ):
-        """Consume matching xmlelements and call parse() on each
+        self,
+        xmlelement: etree._Element,
+        schema: "Schema" = None,
+        allow_none: bool = True,
+        context: XmlParserContext = None,
+        schema_type: "Type" = None,
+    ) -> typing.Optional[typing.Union[str, CompoundValue, typing.List[etree._Element]]]:
+        """Try to parse the xml element and return a value for it.
+
+        There is a big chance that we cannot parse this value since it is an
+        Any. In that case we just return the raw lxml Element nodes.
 
         :param xmlelement: XML element objects
-        :type xmlelement: lxml.etree._Element
         :param schema: The parent XML schema
-        :type schema: zeep.xsd.Schema
         :param allow_none: Allow none
-        :type allow_none: bool
         :param context: Optional parsing context (for inline schemas)
-        :type context: zeep.xsd.context.XmlParserContext
         :param schema_type: The original type (not overriden via xsi:type)
-        :type schema_type: zeep.xsd.types.base.Type
-        :rtype: dict or None
 
         """
         xsi_type = qname_attr(xmlelement, xsi_ns("type"))
@@ -70,13 +94,13 @@ class AnyType(Type):
                 )
 
                 if xmlelement.text:
-                    return xmlelement.text
+                    return self.pythonvalue(xmlelement.text)
                 return children
 
             # If the xsd_type is xsd:anyType then we will recurs so ignore
             # that.
             if isinstance(xsd_type, self.__class__):
-                return xmlelement.text or None
+                return self.pythonvalue(xmlelement.text) or None
 
             return xsd_type.parse_xmlelement(xmlelement, schema, context=context)
 
@@ -107,12 +131,16 @@ class AnyType(Type):
             builtins.Time,
         ]
         for xsd_type in available_types:
-            if isinstance(value, xsd_type.accepted_types):
+            if isinstance(value, tuple(xsd_type.accepted_types)):
                 return xsd_type().xmlvalue(value)
         return str(value)
 
-    def pythonvalue(self, value, schema=None):
-        return value
+    def pythonvalue(self, value, schema=None) -> typing.Optional[str]:
+        return value if value is not None else None
 
     def signature(self, schema=None, standalone=True):
         return "xsd:anyType"
+
+    @threaded_cached_property
+    def _attributes_unwrapped(self):
+        return []
